==> nextcord-ormar-0.3.1.tar.gz: nextcord-ormar-0.3.1/nextcord_ormar/nxalembic/template/env.py <==
from logging.config import fileConfig

from sqlalchemy import engine_from_config
from sqlalchemy import pool

from alembic import context

# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support

# This is set in nxalembic when it grabs the app metadata out of the bot
target_metadata = config.app_metadata
all_tables = config.all_tables
version_table = config.get_main_option("version_table")
# target_metadata = None

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def metadata_has_table(all_tables, table_name):
    return table_name in all_tables


def include_object(object, name, type_, reflected, compare_to):
    if type_ == "table":
        if name in target_metadata.tables:
            return True
        # print(all_tables, name)
        if metadata_has_table(all_tables, name):
            return False
        # If we don't know what this table is, don't touch it
        return False
    else:
        # print(object, name, type_)
        return True


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
        render_as_batch=True,
        version_table=version_table,
        include_object=include_object
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(
            connection=connection, target_metadata=target_metadata,
            render_as_batch=True,
            version_table=version_table,
            include_object=include_object
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()

==> nextcord-ormar-0.3.2.tar.gz: nextcord-ormar-0.3.2/nextcord_ormar/nxalembic/template/env.py <==
from logging.config import fileConfig

from sqlalchemy import engine_from_config
from sqlalchemy import pool

from alembic import context
from nextcord_ormar.nxalembic.exceptions import MigrationIsEmpty

# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support

# This is set in nxalembic when it grabs the app metadata out of the bot
target_metadata = config.app_metadata
all_tables = config.all_tables
version_table = config.get_main_option("version_table")
# target_metadata = None

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def metadata_has_table(all_tables, table_name):
    return table_name in all_tables


def include_object(object, name, type_, reflected, compare_to):
    if type_ == "table":
        if name in target_metadata.tables:
            return True
        # print(all_tables, name)
        if metadata_has_table(all_tables, name):
            return False
        # If we don't know what this table is, don't touch it
        return False
    else:
        # print(object, name, type_)
        return True


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
        render_as_batch=True,
        version_table=version_table,
        include_object=include_object
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(
            connection=connection, target_metadata=target_metadata,
            render_as_batch=True,
            version_table=version_table,
            include_object=include_object
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()


revision_context = context._proxy.context_opts.get("revision_context")
# If we are making migrations
if revision_context:
    # If the migration is empty, don't output anything
    is_empty = True
    for revision in revision_context.generated_revisions:
        if len(revision.downgrade_ops.ops) > 0:
            is_empty = False
        if len(revision.upgrade_ops.ops) > 0:
            is_empty = False

    if is_empty:
        raise MigrationIsEmpty
